@@ -3,22 +3,23 @@ import io
 from datomizer import DatoMapper
 from datomizer.helpers import common_helper
 from datomizer.helpers.train import enhance_ml_helper, train_helper
+from datomizer.helpers.train.enhance_ml_helper import DEFAULT_ALGORITHMS, DEFAULT_METRIC
 from datomizer.utils.general import ID, MODELS, ERROR
-from datomizer.utils.messages import MISSING_TARGET_TABLE
+from datomizer.utils.interfaces import DatoGenInterface
+from datomizer.utils.messages import MISSING_TARGET_COLUMN
 from datomizer.utils.step_types import ML_TRAIN_AND_GENERATE
-from datomizer.utils.enhance_ml import Metrics, Algorithms
+from datomizer.utils.enhance_ml import Metrics, Algorithms, map_enum_list
 from datomizer.utils.enhance_ml import assert_column_valid_for_eml
-from datomizer.protos.autodiscoveryservice_pb2 import TableDTO, ColumnDTO
 
 
-class DatoEnhancer(object):
+class DatoEnhancer(DatoGenInterface):
     dato_mapper: DatoMapper
     train_id = 0
     models = []
     metric_list = []
     algorithm_list = []
-    target_table: TableDTO
-    target_column: ColumnDTO
+    target_table: str
+    target_column: str
 
     def __init__(self, dato_mapper: DatoMapper):
         """Create DatoEnhancer object for enhancing the mapped input data for a specific prediction target.
@@ -36,12 +37,19 @@ class DatoEnhancer(object):
         return dato_enhancer
 
     def generate(self, target_table: str = "", target_column: str = "",
-                 metric_list: [Metrics] = [], algorithm_list: [Algorithms] = [], wait=True) -> None:
-        self.validate_and_set_params(target_table, target_column, metric_list, algorithm_list)
+                 optimize_metric: Metrics = DEFAULT_METRIC, algorithm_list: [Algorithms] = [], wait=True) -> None:
+        """Trains DatoEnhancer object for enhancing the mapped input data for a specific prediction target.
+        Args:
+            target_table: target table name.
+            target_column: target column name.
+            optimize_metric: Metric which you want model to optimize by.
+            algorithm_list: Algorithms list which you want to use.
+            wait: use wait=False for asynchronous programming; True by default (awaits for the results)."""
+        self.validate_and_set_params(target_table, target_column, optimize_metric, algorithm_list)
 
         self.train_id = enhance_ml_helper.enhance_ml_generate(self.dato_mapper,
-                                                              target_table=self.target_table.name,
-                                                              target_column=self.target_column.name,
+                                                              target_table=self.target_table,
+                                                              target_column=self.target_column,
                                                               metric_list=self.metric_list,
                                                               algorithm_list=self.algorithm_list)
         if wait:
@@ -61,13 +69,24 @@ class DatoEnhancer(object):
         train = train_helper.get_train_iteration(self.dato_mapper, self.train_id)
         self.models = train[MODELS]
 
-    def validate_and_set_params(self, target_table, target_column, metric_list, algorithm_list):
-        assert target_column, MISSING_TARGET_TABLE
-        self.target_table = self.dato_mapper.schema.table(target_table)
-        self.target_column = self.dato_mapper.schema.column(target_table, target_column)
-        assert_column_valid_for_eml(self.target_column)
-        self.metric_list = metric_list
-        self.algorithm_list = algorithm_list
+    def validate_and_set_params(self, target_table, target_column, optimize_metric, algorithm_list):
+        assert target_column, MISSING_TARGET_COLUMN
+        self.target_table = self.dato_mapper.schema.table(target_table).name
+
+        column = self.dato_mapper.schema.column(target_table, target_column)
+        assert_column_valid_for_eml(column)
+        self.target_column = column.name
+
+        if not optimize_metric:
+            optimize_metric = DEFAULT_METRIC
+        self.metric_list = map_enum_list([optimize_metric])
+
+        if not algorithm_list:
+            algorithm_list = DEFAULT_ALGORITHMS
+        self.algorithm_list = map_enum_list(algorithm_list)
+
+    def list_tables(self):
+        return self.dato_mapper.schema.tables_name()
 
     def get_generated_data(self, is_full: bool = False) -> None:
         self.restore_validation()
