@@ -2,13 +2,14 @@ import io
 
 from datomizer import DatoTrainer
 from datomizer.helpers.common_helper import get_flow, wait_for_step_type, get_generated_zip, get_generated_csv
-from datomizer.helpers.generator.generator_helper import generate
+from datomizer.helpers.generator.generator_helper import generate, assert_output_ratio
 from datomizer.helpers.datasource.datasource_helper import create_target_private_datasource
 from datomizer.utils.general import TARGET_DATASOURCE_ID, ERROR
+from datomizer.utils.interfaces import DatoGenInterface
 from datomizer.utils.step_types import GENERATE
 
 
-class DatoGenerator(object):
+class DatoGenerator(DatoGenInterface):
     dato_trainer: DatoTrainer
     synth_id = 0
     datasource_id = 0
@@ -43,8 +44,10 @@ class DatoGenerator(object):
     def generate(self, output_ratio: float = 1, wait=True) -> None:
         """Generate output data.
         Args:
-            output_ratio: float represents the output ratio for generated data
+            output_ratio: float represents the output ratio for generated data 0.1 - 20.0
             wait: use wait=False for asynchronous programming; True by default (awaits for the results)."""
+        assert_output_ratio(output_ratio)
+
         self.create_datasource()
         if self.synth_id > 0:
             return
@@ -65,6 +68,9 @@ class DatoGenerator(object):
             raise Exception("Synth Failed")
         self.datasource_id = self.get_flow()[TARGET_DATASOURCE_ID]
 
+    def list_tables(self):
+        return self.dato_trainer.dato_mapper.schema.tables_name()
+
     def get_generated_data(self) -> None:
         self.restore_validation()
         print(get_generated_zip(datomizer=self.dato_trainer.dato_mapper.datomizer,
