@@ -7,10 +7,11 @@ from datomizer.helpers.business_unit_project.business_unit_project_helper import
 from datomizer.helpers.autodiscovery.autodiscovery_helper import discover, get_schema_discovery, put_schema_discovery
 from datomizer.helpers.wrapper.schema_wrapper import SchemaWrapper
 from datomizer.utils.general import ORIGIN_DATASOURCE_ID, ERROR
+from datomizer.utils.interfaces import DatoCommonInterface
 from datomizer.utils.step_types import COLUMN_DISCOVERY
 
 
-class DatoMapper(object):
+class DatoMapper(DatoCommonInterface):
     datomizer: Datomizer
     business_unit_id = 0
     project_id = 0
@@ -97,6 +98,9 @@ class DatoMapper(object):
                                                          self.schema.schema))
         return self.schema
 
+    def list_tables(self):
+        return self.schema.tables_name()
+
     def base_validation(self):
         assert (self.business_unit_id > 0 and self.project_id > 0), "missing base properties"
 
