@@ -5,10 +5,11 @@ from datomizer.helpers.common_helper import wait_for_step_type, get_generated_zi
 from datomizer.helpers.train.train_helper import train, get_train_iteration, get_evaluation
 from datomizer.helpers.wrapper.evaluation_wrapper import EvaluationWrapper
 from datomizer.utils.general import ID, MODELS, ERROR
+from datomizer.utils.interfaces import DatoGenInterface
 from datomizer.utils.step_types import TRAIN_AND_GENERATE
 
 
-class DatoTrainer(object):
+class DatoTrainer(DatoGenInterface):
     dato_mapper: DatoMapper
     train_id = 0
     model_id = 0
@@ -19,6 +20,7 @@ class DatoTrainer(object):
             dato_mapper: the DatoMapper object for the input data."""
         dato_mapper.next_step_validation()
         self.dato_mapper = dato_mapper
+        self.dato_mapper.get_schema()
 
     @classmethod
     def restore(cls, dato_mapper: DatoMapper, train_id):
@@ -27,13 +29,15 @@ class DatoTrainer(object):
         dato_trainer.wait()
         return dato_trainer
 
-    def train(self, wait=True) -> None:
+    def train(self, epochs_gan=500, epochs_vae=300, wait=True) -> None:
         """Train a generative model.
         Args:
+            epochs_gan: number of epochs for gan model
+            epochs_vae: number of epochs for vae model
             wait: use wait=False for asynchronous programming; True by default (awaits for the results)."""
         if self.train_id > 0:
             return
-        self.train_id = train(self.dato_mapper)
+        self.train_id = train(self.dato_mapper, epochs_gan, epochs_vae)
         if wait:
             self.wait()
 
@@ -50,6 +54,9 @@ class DatoTrainer(object):
             raise Exception("Trainer Failed")
         self.model_id = get_train_iteration(self.dato_mapper, self.train_id)[MODELS][0][ID]
 
+    def list_tables(self):
+        return self.dato_mapper.schema.tables_name()
+
     def get_generated_data(self) -> None:
         self.next_step_validation()
         print(get_generated_zip(datomizer=self.dato_mapper.datomizer,
