@@ -11,19 +11,11 @@ DEFAULT_ALGORITHMS = [Algorithms.RANDOM_FOREST,
                       Algorithms.LR,
                       Algorithms.LGBM,
                       Algorithms.XGBOOST]
-DEFAULT_METRICS = [Metrics.F1,
-                   Metrics.PR_AUC]
+DEFAULT_METRIC = Metrics.F1
 
 
 def create_enhance_ml_request(target_table, target_column,
                               metric_list=[], algorithm_list=[]) -> dict:
-    if not metric_list:
-        metric_list = DEFAULT_METRICS
-    if not algorithm_list:
-        algorithm_list = DEFAULT_ALGORITHMS
-
-    metric_list = map_enum_list(metric_list)
-    algorithm_list = map_enum_list(algorithm_list)
 
     return {"tableName": target_table, "targetColumn": target_column,
             "metricList": metric_list, "algorithmList": algorithm_list}
