@@ -12,6 +12,9 @@ class SchemaWrapper(object):
     def tables(self) -> list:
         return self.schema.tables
 
+    def tables_name(self) -> list:
+        return map(lambda table: table.name, self.schema.tables)
+
     def table(self, table_name=None) -> TableDTO:
         tables = self.tables()
         table: TableDTO
