@@ -50,6 +50,8 @@ GENERATED_DATA_CSV = "/generatedTableCSV"
 TRAIN = "/train"
 TRAIN_AND_GENERATE = "/trainAndGenerate"
 ENHANCE_ML = "/enhanceMLFlows"
+DATA_TUNER = "/DTFlows"
+RULES_PATH = "/putRulesPath"
 ENHANCE_ML_EVALUATE = "/enhancedMLEvaluate"
 ENHANCE_ML_TRAIN_GEN = "/enhancedMLTrainAndGenerate"
 MODEL = "/models"
@@ -61,17 +63,26 @@ EVALUATION = "/validationSummary"
 SINGLE_PROJECT_URL = URL + MANAGEMENT + BUSINESS_UNIT_URL + "/%s" + PROJECT_URL + "/%s"
 
 MANAGEMENT_GET_ALL_BUSINESS_UNIT_URL = URL + MANAGEMENT + BUSINESS_UNIT_URL
+
 MANAGEMENT_GET_GENERATIVE_FLOW = SINGLE_PROJECT_URL + GENERATIVE_MODEL + "/%s"
 MANAGEMENT_GET_SYNTH_FLOW = SINGLE_PROJECT_URL + SYNTH_FLOW + "/%s"
+
 MANAGEMENT_POST_ADD_FLOW = SINGLE_PROJECT_URL + GENERATIVE_MODEL
+
 MANAGEMENT_GET_SCHEMA_DISCOVERY = SINGLE_PROJECT_URL + FLOWS_URL + "/%s" + AUTO_SCHEMA_DISCOVERY
 MANAGEMENT_GET_SCHEMA_DISCOVERY_PROTO = SINGLE_PROJECT_URL + FLOWS_URL + "/%s" + AUTO_SCHEMA_DISCOVERY + PROTO
+
 MANAGEMENT_PUT_TRAIN_FLOW = SINGLE_PROJECT_URL + GENERATIVE_MODEL + "/%s" + TRAIN_AND_GENERATE
 MANAGEMENT_PUT_ENHANCE_ML_EVALUATE_FLOW = SINGLE_PROJECT_URL + ENHANCE_ML + "/%s" + ENHANCE_ML_EVALUATE
 MANAGEMENT_PUT_ENHANCE_ML_TRAIN_GEN_FLOW = SINGLE_PROJECT_URL + ENHANCE_ML + "/%s" + ENHANCE_ML_TRAIN_GEN
+MANAGEMENT_PUT_DATA_TUNER_TRAIN_GEN_FLOW = SINGLE_PROJECT_URL + DATA_TUNER + "/%s" + TRAIN_AND_GENERATE
+
+MANAGEMENT_PUT_DATA_TUNER_RULES_PATH = SINGLE_PROJECT_URL + DATA_TUNER + "/%s" + RULES_PATH + PROTO
+
 MANAGEMENT_GET_GENERATIVE_SAMPLE = SINGLE_PROJECT_URL + GENERATIVE_MODEL + "/%s" + MODEL + "/%s" + SAMPLE_TABLE + "/%s"
 MANAGEMENT_GET_MODEL_EVALUATION = SINGLE_PROJECT_URL + GENERATIVE_MODEL + "/%s" + MODEL + "/%s" + EVALUATION
 MANAGEMENT_GET_GENERATED_DATA = SINGLE_PROJECT_URL + SYNTH_FLOW + "/%s" + TRAIN + "/%s" + MODEL + "/%s" + GENERATED_DATA
 MANAGEMENT_GET_GENERATED_DATA_CSV = SINGLE_PROJECT_URL + SYNTH_FLOW + "/%s" + TRAIN + "/%s" + MODEL + "/%s" + GENERATED_DATA_CSV + "/%s"
 MANAGEMENT_GET_SAMPLE_CSV = SINGLE_PROJECT_URL + SYNTH_FLOW + "/%s" + SAMPLE_DATA_CSV + "/%s"
+
 MANAGEMENT_PUT_SYNTH_FLOW = SINGLE_PROJECT_URL + SYNTH_FLOW + "/%s" + SYNTHESIZE
