@@ -1,4 +1,7 @@
 import enum
+from datomizer.protos.autodiscoveryservice_pb2 import ColumnDTO
+from datomizer.utils.schema import Roles
+from datomizer.utils.messages import EML_TARGET_INVALID_ROLE, EML_TARGET_INVALID_UNIQUE_COUNT
 
 
 class Algorithms(enum.Enum):
@@ -36,3 +39,8 @@ class Metrics(enum.Enum):
 
 def map_enum_list(enum_list: []):
     return [obj.value for obj in enum_list]
+
+
+def assert_column_valid_for_eml(column: ColumnDTO):
+    assert column.role == Roles.LABEL.value, EML_TARGET_INVALID_ROLE
+    assert 2 <= column.uniqueCount <= 10, EML_TARGET_INVALID_UNIQUE_COUNT
